summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Newline.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Newline.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Newline.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Newline.php b/includes/pear/Text/Wiki/Parse/Default/Newline.php
index 495b7d7..ff666db 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Newline.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Newline.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Newline.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -20,7 +20,7 @@
*
* Parses for implied line breaks indicated by newlines.
*
* This class implements a Text_Wiki_Parse to mark implied line breaks in the
* source text, usually a single carriage return in the middle of a paragraph
* or block-quoted text.
*
@@ -32,7 +32,7 @@
*
*/
-class Text_Wiki_Parse_Newline extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Newline extends Text_Wiki_Parse {
/**
@@ -72,4 +72,4 @@ class Text_Wiki_Parse_Newline extends Text_Wiki_Parse {
}
}
-?> \ No newline at end of file
+?>
@@ -20,7 +20,7 @@
* Parses for implied line breaks indicated by newlines.
*
-* This class implements a Text_Wiki_Parse to mark implied line breaks in the
+* This class implements a Text_Wiki_Parse_Default to mark implied line breaks in the
* source text, usually a single carriage return in the middle of a paragraph
* or block-quoted text.